@@ -7,16 +7,10 @@ INDEX
 INDEX
 	environ
 
-ANSI_SYNOPSIS
+SYNOPSIS
 	#include <stdlib.h>
 	char *_getenv_r(struct _reent *<[reent_ptr]>, const char *<[name]>);
 
-TRAD_SYNOPSIS
-	#include <stdlib.h>
-	char *_getenv_r(<[reent_ptr]>, <[name]>)
-	struct _reent *<[reent_ptr]>;
-	char *<[name]>;
-
 DESCRIPTION
 <<_getenv_r>> searches the list of environment variable names and values
 (using the global pointer ``<<char **environ>>'') for a variable whose
@@ -48,9 +42,8 @@ permit '=' to be in identifiers.
  * notice and comment, and (2) distributions including binaries display
  * the following acknowledgement:  ``This product includes software
  * developed by the University of California, Berkeley and its contributors''
- * in the documentation or other materials provided with the distribution
- * and in all advertising materials mentioning features or use of this
- * software. Neither the name of the University nor the names of its
+ * in the documentation or other materials provided with the distribution.
+ * Neither the name of the University nor the names of its
  * contributors may be used to endorse or promote products derived
  * from this software without specific prior written permission.
  * THIS SOFTWARE IS PROVIDED ``AS IS'' AND WITHOUT ANY EXPRESS OR
@@ -80,14 +73,13 @@ static char ***p_environ = &environ;
  */
 
 char *
-_DEFUN (_findenv_r, (reent_ptr, name, offset),
-        struct _reent *reent_ptr   _AND
-	register _CONST char *name _AND
+_findenv_r (struct _reent *reent_ptr,
+	register const char *name,
 	int *offset)
 {
   register int len;
   register char **p;
-  _CONST char *c;
+  const char *c;
 
   ENV_LOCK;
 
@@ -125,9 +117,8 @@ _DEFUN (_findenv_r, (reent_ptr, name, offset),
  */
 
 char *
-_DEFUN (_getenv_r, (reent_ptr, name),
-        struct _reent *reent_ptr _AND
-	_CONST char *name)
+_getenv_r (struct _reent *reent_ptr,
+	const char *name)
 {
   int offset;
 
