@@ -16,9 +16,7 @@ getlogin ()
   extern char *ttyname ();
   char *tty;
 
-  if (((tty = ttyname (0)) == 0)
-      || ((tty = ttyname (1)) == 0)
-      || ((tty = ttyname (2)) == 0))
+  if ((tty = ttyname (0)) == 0)
     return 0;
 
   if ((utmp_fd = open (UTMP_FILE, O_RDONLY)) == -1)
